==> lat-0.0.1.tar.gz: lat-0.0.1/setup.py <==
import pathlib
from setuptools import setup, find_packages
import toml

def get_install_requirements():
    try:
        # read my pipfile
        with open ('Pipfile', 'r') as fh:
            pipfile = fh.read()
        # parse the toml
        pipfile_toml = toml.loads(pipfile)
        
    except FileNotFoundError:
        return []

    try:
        required_packages = pipfile_toml['packages'].items()

        # if the package's key isn't there then just return an empty
        # list
        
        # If a version/range is specified in the Pipfile honor it
        # otherwise just list the package
        return ["{0}{1}".format(pkg,ver) 
                if ver != "*" else pkg for pkg,ver in required_packages]

    except KeyError:
        return []

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

# This call to setup() does all the work
setup(
    name="lat",
    version="0.0.1",
    description="exploring lat-cli",
    long_description=README,
    long_description_content_type="text/markdown",
    #url="https://gitlab.com/python-cicd/k9",
    author="SimonComputing, Inc.",
    author_email="lat@simoncomputing.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.10",
    ],
    packages=find_packages(exclude=("test", "venv", "doc_build", "doc_source", "build", "dist")),
    include_package_data=True,
    install_requires=get_install_requirements(),
    entry_points={
        "console_scripts": [
            "lat=latclidir.cli:main",
        ]
    },
)

==> lat-0.0.2.tar.gz: lat-0.0.2/setup.py <==
import pathlib
from setuptools import setup, find_packages
import toml

def get_install_requirements():
    try:
        # read my pipfile
        with open ('Pipfile', 'r') as fh:
            pipfile = fh.read()
        # parse the toml
        pipfile_toml = toml.loads(pipfile)
        
    except FileNotFoundError:
        return []

    try:
        required_packages = pipfile_toml['packages'].items()

        # if the package's key isn't there then just return an empty
        # list
        
        # If a version/range is specified in the Pipfile honor it
        # otherwise just list the package
        return ["{0}{1}".format(pkg,ver) 
                if ver != "*" else pkg for pkg,ver in required_packages]

    except KeyError:
        return []

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

# This call to setup() does all the work
setup(
    name="lat",
    version="0.0.2",
    description="exploring lat-cli",
    long_description=README,
    long_description_content_type="text/markdown",
    #url="https://gitlab.com/python-cicd/k9",
    author="SimonComputing, Inc.",
    author_email="lat@simoncomputing.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.10",
    ],
    packages=find_packages(exclude=("test", "venv", "doc_build", "doc_source", "build", "dist")),
    include_package_data=True,
    install_requires=get_install_requirements(),
    entry_points={
        "console_scripts": [
            "lat=latclidir.latcli:main",
        ]
    },
)
